@@ -1,4 +1,4 @@
-/* $Id: bogolexer.c 6714 2008-04-20 15:27:06Z relson $ */
+/* $Id: bogolexer.c 6766 2009-01-12 04:27:36Z relson $ */
 
 /*****************************************************************************
 
@@ -71,7 +71,7 @@ static void print_version(void)
 {
     (void)fprintf(stdout,
 		  "%s version %s\n"
-		  "Copyright (C) 2002-2007 David Relson\n\n"
+		  "Copyright (C) 2002-2009 David Relson\n\n"
 		  "%s comes with ABSOLUTELY NO WARRANTY.  "
 		  "This is free software, and\nyou are welcome to "
 		  "redistribute it under the General Public License.  "
@@ -323,10 +323,10 @@ int main(int argc, char **argv)
 	{
 	    count += 1;
 	    if (passthrough) {
-		fprintf(fpo, "%s\n", token.text);
+		fprintf(fpo, "%s\n", token.u.text);
 	    }
 	    else if (!quiet)
-		fprintf(fpo, "get_token: %d \"%s\"\n", (int)t, token.text);
+		fprintf(fpo, "get_token: %d \"%s\"\n", (int)t, token.u.text);
 	}
     }
 
