@@ -1,4 +1,4 @@
-/* $Id: bogotune.c 6718 2008-04-26 12:51:10Z relson $ */
+/* $Id: bogotune.c 6806 2009-02-19 04:41:50Z relson $ */
 
 /*****************************************************************************
 
@@ -385,7 +385,7 @@ static void score_ns(double *results)
 	mlitem_t *item;
 	for (item = list->head; item != NULL; item = item->next) {
 	    wordhash_t *wh = item->wh;
-	    double score = msg_compute_spamicity(wh, NULL);
+	    double score = msg_compute_spamicity(wh);
 	    results[count++] = score;
 	    if ( -verbose == SCORE_DETAIL ||
 		(-verbose >= SCORE_DETAIL && EPS < score && score < 1 - EPS))
@@ -435,7 +435,7 @@ static void score_sp(double *results)
 	mlitem_t *item;
 	for (item = list->head; item != NULL; item = item->next) {
 	    wordhash_t *wh = item->wh;
-	    double score = msg_compute_spamicity(wh, NULL);
+	    double score = msg_compute_spamicity(wh);
 	    results[count++] = score;
 	    if ( -verbose == SCORE_DETAIL ||
 		(-verbose >= SCORE_DETAIL && EPS < score && score < 1 - EPS))
@@ -639,7 +639,7 @@ static int update_count(void)
 	if ((message_count % 1000) != 0)
 	    putchar('.');
 	else
-	    printf("\r              \r%u ", message_count/1000 );
+	    printf("\r              \r%u ", message_count );
 	fflush(stdout);
     }
     return message_count;
@@ -732,7 +732,7 @@ static void write_msgcount_file(wordhash_t *wh)
 
     for (hn = wordhash_first(wh); hn != NULL; hn = wordhash_next(wh)) {
 	word_t *token = hn->key;
-	wordprop_t *wp = (wordprop_t *) hn->buf;
+	wordprop_t *wp = (wordprop_t *) hn->data;
 	wordcnts_t *cnts = &wp->cnts;
 
 	if (cnts->good == 0 && cnts->bad == 0) {
@@ -743,7 +743,7 @@ static void write_msgcount_file(wordhash_t *wh)
 	    }
 	}
 
-	print_msgcount_entry((char *)token->text, cnts->bad, cnts->good);
+	print_msgcount_entry((char *)token->u.text, cnts->bad, cnts->good);
     }
 
     return;
@@ -947,6 +947,7 @@ static void help(void)
 static struct option longopts_bogotune[] = {
     /* longoptions.h - common options */
     LONGOPTIONS_COMMON
+    LONGOPTIONS_MAIN_TUNE
     /* longoptions.h - bogofilter/-lexer options */
     LONGOPTIONS_LEX
     /* end of list */
@@ -1125,6 +1126,18 @@ int process_arg(int option, const char *name, const char *val, priority_t preced
 	replace_nonascii_characters = get_bool(name, val);
 	break;
 
+    case O_TOKEN_COUNT_FIX:
+	token_count_fix = atoi(val);
+	break;
+
+    case O_TOKEN_COUNT_MIN:
+	token_count_min = atoi(val);
+	break;
+
+    case O_TOKEN_COUNT_MAX:
+	token_count_max = atoi(val);
+	break;
+
     default:
 	help();
 	exit(EX_ERROR);
@@ -1462,6 +1475,7 @@ static bool check_msgcount_parms(void)
 static bool check_msg_counts(void)
 {
     bool ok = true;
+    double ratio;
 
     if (msgs_good < LIST_COUNT || msgs_bad < LIST_COUNT) {
 	if (!quiet)
@@ -1472,13 +1486,13 @@ static bool check_msg_counts(void)
 	ok = false;
     }
 
-    if (msgs_bad * 5.0 < msgs_good ||
-	msgs_bad > msgs_good * 5.0) {
-	if (!quiet)
+    ratio =  (double)msgs_good / (double)msgs_bad;
+    fprintf(stderr, "wordlist's ham to spam ratio is %0.1f to 1.0\n", ratio );
+    if ( ratio < 0.1 || ratio > 10.0) {
+	if (!quiet) {
 	    fprintf(stderr,
-		    "The wordlist has a ratio of spam to non-spam of %0.1f to 1.0.\n"
-		    "Bogotune requires the ratio be in the range of 0.2 to 5.\n",
-		    (double)msgs_bad / msgs_good);
+		    "Bogotune requires the ratio be in the range of 0.1 to 10.\n");
+	}
 	ok = false;
     }
 
