@@ -1,4 +1,4 @@
-/* $Id: format.c 6535 2006-07-04 12:53:30Z relson $ */
+/* $Id: format.c 6789 2009-02-12 01:12:53Z relson $ */
 
 /*****************************************************************************
 
@@ -325,7 +325,7 @@ char *convert_format_to_string(char *buff, size_t size, const char *format)
 		*buff++ = '%';
 		break;
 	    case 'A':		/* A - Message Address */
-		buff += format_string(buff, (*msg_addr->text != '\0') ? (const char *)msg_addr->text : "UNKNOWN", 0, prec, flags, end);
+		buff += format_string(buff, (*msg_addr->u.text != '\0') ? (const char *)msg_addr->u.text : "UNKNOWN", 0, prec, flags, end);
 		break;
 	    case 'c':		/* c - classification, e.g. Yes/No, Spam/Ham/Unsure, or YN, SHU, +-? */
 	    {
@@ -347,10 +347,10 @@ char *convert_format_to_string(char *buff, size_t size, const char *format)
 		break;
 	    }
 	    case 'I':		/* M - Message ID */
-		buff += format_string(buff, (*msg_id->text != '\0') ? (const char *)msg_id->text : "UNKNOWN", 0, prec, flags, end);
+		buff += format_string(buff, (*msg_id->u.text != '\0') ? (const char *)msg_id->u.text : "UNKNOWN", 0, prec, flags, end);
 		break;
 	    case 'Q':		/* Q - Queue ID */
-		buff += format_string(buff, (*queue_id->text != '\0') ? (const char *)queue_id->text : "UNKNOWN", 0, prec, flags, end);
+		buff += format_string(buff, (*queue_id->u.text != '\0') ? (const char *)queue_id->u.text : "UNKNOWN", 0, prec, flags, end);
 		break;
 	    case 'p':		/* p - spamicity as a probability */
 	    {
@@ -434,12 +434,16 @@ char *format_terse(char *buff, size_t size)
     return convert_format_to_string( buff, size, terse_format );
 }
 
-char *format_log_update(char *buff, size_t size, const char *_reg, const char *_unreg, uint _wrd, uint _msg)
+void format_set_counts(uint _wrd, uint _msg)
+{
+    wrdcount = _wrd;
+    msgcount = _msg;
+}
+
+char *format_log_update(char *buff, size_t size, const char *_reg, const char *_unreg)
 {
     reg = _reg;
     unreg = _unreg;
-    wrdcount = _wrd;
-    msgcount = _msg;
     return convert_format_to_string( buff, size, log_update_format );
 }
 
