@@ -1,4 +1,4 @@
-/* $Id: robx.c 5967 2005-05-19 12:14:39Z m-a $ */
+/* $Id: robx.c 6766 2009-01-12 04:27:36Z relson $ */
 
 /*****************************************************************************
 
@@ -51,7 +51,7 @@ static void robx_accum(rhd_t *rh,
 		"  sp: %3lu,  gd: %3lu,  p: %9.6f,  t: %.*s\n", 
 		(unsigned long)rh->count, rh->sum, rh->sum / rh->count,
 		(unsigned long)spamness, (unsigned long)goodness, prob,
-		CLAMP_INT_MAX(key->leng), key->text);
+		CLAMP_INT_MAX(key->leng), key->u.text);
     }
 }
 
@@ -61,7 +61,7 @@ static int robx_hook(word_t *key, dsv_t *data,
     struct robhook_data *rh = userdata;
 
     /* ignore system meta-data */
-    if (*key->text != '.')
+    if (*key->u.text != '.')
 	robx_accum(rh, key, data);
 
     return 0;
