@@ -1,4 +1,4 @@
-/* $Id: score.c 6712 2008-04-19 02:33:29Z relson $ */
+/* $Id: score.c 6816 2009-02-21 21:11:01Z relson $ */
 
 /*****************************************************************************
 
@@ -17,6 +17,7 @@ NAME:
 #include "bogofilter.h"
 #include "collect.h"
 #include "datastore.h"
+#include "listsort.h"
 #include "msgcounts.h"
 #include "prob.h"
 #include "rand_sleep.h"
@@ -40,13 +41,36 @@ NAME:
 #include "gsl/gsl_cdf.h"
 #endif
 
+/* Structure Definitions */
+
+typedef struct probnode_t {
+    hashnode_t * node;
+    double	 prob;
+} probnode_t;
+
+/* struct for saving stats for printing. */
+typedef struct score_s {
+    double min_dev;
+    double spamicity;
+    u_int32_t robn;
+    double p_ln;	/* Robinson P, as a log*/
+    double q_ln;	/* Robinson Q, as a log*/
+    double p_pr;	/* Robinson P */
+    double q_pr;	/* Robinson Q */
+} score_t;
+
 /* Function Prototypes */
 
 static	double	get_spamicity(size_t robn, FLOAT P, FLOAT Q);
+static	bool	need_scoring_boundary(size_t count);
+static	double	find_scoring_boundary(wordhash_t *wh);
+static	size_t	compute_count_and_scores(wordhash_t *wh);
+static	size_t	compute_count_and_spamicity(wordhash_t *wh, FLOAT *P, FLOAT *Q, bool need_stats);
+static	int	compare_hashnode_t(const void *const pv1, const void *const pv2);
 
 /* Static Variables */
 
-static score_t  score;
+static score_t	score;
 
 /* Function Definitions */
 
@@ -174,7 +198,7 @@ retry:
     for (node = wordhash_first(wh); node != NULL; node = wordhash_next(wh))
     {
 	word_t *token     = node->key;
-	wordprop_t *props = (wordprop_t *) node->buf;
+	wordprop_t *props = (wordprop_t *) node->data;
 	wordcnts_t *cnts  = &props->cnts;
 	ret = lookup(token, cnts);
 	if (ret == DS_ABORT_RETRY)
@@ -186,87 +210,38 @@ retry:
     return;
 }
 
-
 /** selects the best spam/non-spam indicators and calculates Robinson's S,
  * \return -1.0 for error, S otherwise */
-double msg_compute_spamicity(wordhash_t *wh, FILE *fp) /*@globals errno@*/
+double msg_compute_spamicity(wordhash_t *wh) /*@globals errno@*/
 {
-    hashnode_t *node;
-
     FLOAT P = {1.0, 0};		/* Robinson's P */
     FLOAT Q = {1.0, 0};		/* Robinson's Q */
 
     double spamicity;
-    int    err = 0;
     size_t robn = 0;
-    size_t count = 0;
-    bool need_stats = (Rtable || passthrough || (verbose > 0)) && !fBogotune;
 
-    (void) fp;			/* suppress compiler warning */
+    bool need_stats = !fBogotune && (Rtable || passthrough || (verbose > 0));
 
     if (DEBUG_ALGORITHM(2)) fprintf(dbgout, "### msg_compute_spamicity() begins\n");
 
     if (DEBUG_ALGORITHM(2)) fprintf(dbgout, "min_dev: %f, robs: %f, robx: %f\n", 
 				    min_dev, robs, robx);
 
-    for (node = wordhash_first(wh); node != NULL; node = wordhash_next(wh))
-    {
-	double prob;
-	word_t *token;
-	wordcnts_t *cnts;
-	wordprop_t *props;
+    /* compute scores for the wordhash's tokens */
+    robn = compute_count_and_scores(wh);
 
-	if (!fBogotune) {
-	    props = (wordprop_t *) node->buf;
-	    cnts  = &props->cnts;
-	    token = node->key;
-	} else {
-	    cnts = (wordcnts_t *) node;
-	    token = NULL;
-	}
+    /* recalculate min_dev if necessary to satisfy token_count settings */
+    if (!need_scoring_boundary(robn))
+	score.min_dev = min_dev;
+    else
+	score.min_dev = find_scoring_boundary(wh);
 
-	count += 1;
-
-	prob = calc_prob(cnts->good, cnts->bad,
-			 cnts->msgs_good, cnts->msgs_bad);
-
-	if (need_stats)
-	    rstats_add(token, prob, cnts);
-
-	/* Robinson's P and Q; accumulation step */
-	/*
-	 * P = 1 - ((1-p1)*(1-p2)*...*(1-pn))^(1/n)     [spamminess]
-	 * Q = 1 - (p1*p2*...*pn)^(1/n)                 [non-spamminess]
-	 */
-	if (fabs(EVEN_ODDS - prob) - min_dev >= EPS) {
-	    int e;
-
-	    P.mant *= 1-prob;
-	    if (P.mant < 1.0e-200) {
-		P.mant = frexp(P.mant, &e);
-		P.exp += e;
-	    }
-
-	    Q.mant *= prob;
-	    if (Q.mant < 1.0e-200) {
-		Q.mant = frexp(Q.mant, &e);
-		Q.exp += e;
-	    }
-	    robn ++;
-	}
-
-	if (DEBUG_ALGORITHM(3)) {
-	    (void)fprintf(dbgout, "%3lu %3lu %f ",
-			  (unsigned long)robn, (unsigned long)count, prob);
-	    (void)word_puts(token, 0, dbgout);
-	    (void)fputc('\n', dbgout);
-	}
-    }
+    /* compute message spamicity from the wordhash's scores */
+    robn = compute_count_and_spamicity(wh, &P, &Q, need_stats);
 
     /* Robinson's P, Q and S
-    ** S = (P - Q) / (P + Q)                        [combined indicator]
+    ** S = (P - Q) / (P + Q)			    [combined indicator]
     */
-
     spamicity = get_spamicity(robn, P, Q);
 
     if (need_stats && robn != 0)
@@ -274,7 +249,208 @@ double msg_compute_spamicity(wordhash_t *wh, FILE *fp) /*@globals errno@*/
 
     if (DEBUG_ALGORITHM(2)) fprintf(dbgout, "### msg_compute_spamicity() ends\n");
 
-    return err ? -1.0 : spamicity;
+    return spamicity;
+}
+
+/*
+** compute_count_and_scores()
+**	compute the token probabilities from the linked list of tokens
+*/
+static size_t compute_count_and_scores(wordhash_t *wh)
+{
+    size_t count = 0;
+    hashnode_t *node;
+
+    if (fBogotune)
+	return count;
+
+    for (node = wordhash_first(wh); node != NULL; node = wordhash_next(wh))
+    {
+	wordcnts_t *cnts;
+	wordprop_t *props;
+
+	props = (wordprop_t *) node->data;
+	cnts  = &props->cnts;
+	props->prob = calc_prob(cnts->good, cnts->bad,
+				cnts->msgs_good, cnts->msgs_bad);
+	props->used = fabs(props->prob - EVEN_ODDS) > min_dev;
+	if (props->used)
+	    count += 1;
+    }
+
+    return count;
+}
+
+/*
+** compute_count_and_score()
+**	compute the spamicity from the linked list of tokens using
+**	min_dev to select tokens
+*/
+static size_t compute_count_and_spamicity(wordhash_t *wh, 
+					  FLOAT *P, FLOAT *Q,
+					  bool need_stats)
+{
+    size_t count = 0;
+
+    hashnode_t *node;
+
+    for (node = wordhash_first(wh); node != NULL; node = wordhash_next(wh))
+    {
+	bool useflag;
+	double prob;
+	word_t *token;
+	wordcnts_t *cnts;
+	wordprop_t *props;
+
+	if (!fBogotune) {
+	    token = node->key;
+	    props = (wordprop_t *) node->data;
+	    cnts  = &props->cnts;
+	    prob = props->prob;
+	    useflag = props->used;
+	} else {
+	    token = NULL;
+	    cnts = (wordcnts_t *) node;
+	    prob = calc_prob(cnts->good, cnts->bad,
+			     cnts->msgs_good, cnts->msgs_bad);
+	    useflag = fabs(prob - EVEN_ODDS) > score.min_dev;
+	}
+
+	if (need_stats)
+	    rstats_add(token, prob, useflag, cnts);
+
+	/* Robinson's P and Q; accumulation step */
+	/*
+	 * P = 1 - ((1-p1)*(1-p2)*...*(1-pn))^(1/n)	[spamminess]
+	 * Q = 1 - (p1*p2*...*pn)^(1/n)			[non-spamminess]
+	 */
+	if (useflag ) {
+	    int e;
+
+	    P->mant *= 1-prob;
+	    if (P->mant < 1.0e-200) {
+		P->mant = frexp(P->mant, &e);
+		P->exp += e;
+	    }
+
+	    Q->mant *= prob;
+	    if (Q->mant < 1.0e-200) {
+		Q->mant = frexp(Q->mant, &e);
+		Q->exp += e;
+	    }
+	    count += 1;
+	}
+
+	if (DEBUG_ALGORITHM(3)) {
+	    (void)fprintf(dbgout, "%3lu %3lu %f ",
+			  (unsigned long)count, (unsigned long)count, prob);
+	    (void)word_puts(token, 0, dbgout);
+	    (void)fputc('\n', dbgout);
+	}
+    }
+
+    return count;
+}
+
+/* need_scoring_boundary( )
+**	determine if min_dev gives a count fitting the token count limits
+**	return True if so; False if not
+*/
+static bool need_scoring_boundary(size_t count)
+{
+    // Early out if no token count limits are set
+    if (((token_count_min == 0) || (token_count_min <= count)) &&
+	((token_count_max == 0) || (token_count_max >= count)) &&
+	((token_count_fix == 0) || (token_count_fix == count)))
+	return false;
+    else
+	return true;
+}
+
+/* find_scoring_boundary( )
+**	determine the token score that gives the desired token count
+**	for scoring the message.
+*/
+static double find_scoring_boundary(wordhash_t *wh)
+{
+    size_t count = 0;
+
+    double min_prob = (token_count_max == 0.0) ? min_dev : 1.0;
+
+    hashnode_t *node;
+
+    /* sort by ascending score difference (from 0.5) */
+    wh->iter_head = (hashnode_t *)listsort((element *)wh->iter_head, (fcn_compare *)&compare_hashnode_t);
+
+    count = max(token_count_fix, max(token_count_min, token_count_max));
+
+    for (node = wordhash_first(wh); node != NULL; node = wordhash_next(wh)) {
+	wordcnts_t *cnts;
+	wordprop_t *props = NULL;
+	double prob;
+	double dev;
+
+	if (!fBogotune) {
+	    props = (wordprop_t *) node->data;
+	    cnts  = &props->cnts;
+	} else {
+	    cnts = (wordcnts_t *) node;
+	}
+	prob = calc_prob(cnts->good, cnts->bad,
+			 cnts->msgs_good, cnts->msgs_bad);
+	dev = fabs(prob - EVEN_ODDS);
+
+	if (count > 0) {
+	    count -= 1;
+	    if (!fBogotune)
+		props->used = true;
+	    min_prob = dev;
+	}
+	else if (dev >= min_prob) {
+	    if (!fBogotune)
+		props->used = true;
+	}
+	else {
+	    if (!fBogotune)
+		props->used = false;
+	}
+    }
+
+    return min_prob;
+}
+
+/* compare_hashnode_t - sort by ascending score difference (from 0.5) */
+
+static int compare_hashnode_t(const void *const pv1, const void *const pv2)
+{
+    double d1;
+    double d2;
+
+    if (!fBogotune) {
+	const hashnode_t *hn1 = (const hashnode_t const *)pv1;
+	const hashnode_t *hn2 = (const hashnode_t const *)pv2;
+	d1 = fabs(((wordprop_t *) hn1->data)->prob - EVEN_ODDS);
+	d2 = fabs(((wordprop_t *) hn2->data)->prob - EVEN_ODDS);
+    } else {
+	const wordcnts_t *cnts;
+	double prob;
+	cnts = (const wordcnts_t *) pv1;
+	prob = calc_prob(cnts->good, cnts->bad,
+			 cnts->msgs_good, cnts->msgs_bad);
+	d1 = fabs(prob - EVEN_ODDS);
+
+	cnts = (const wordcnts_t *) pv2;
+	prob = calc_prob(cnts->good, cnts->bad,
+			 cnts->msgs_good, cnts->msgs_bad);
+	d2 = fabs(prob - EVEN_ODDS);
+    }
+
+    if (d1 < d2)
+	return +1;
+    if (d1 > d2)
+	return -1;
+
+    return 0;
 }
 
 void score_initialize(void)
@@ -283,8 +459,6 @@ void score_initialize(void)
 
     wordlist_t *list = get_default_wordlist(word_lists);
 
-    rstats_init();
-
     if (fabs(min_dev) < EPS)
 	min_dev = MIN_DEV;
     if (spam_cutoff < EPS)
@@ -333,7 +507,7 @@ void score_initialize(void)
 
 void score_cleanup(void)
 {
-    rstats_cleanup();
+//    rstats_cleanup();
 }
 
 #ifdef GSL_INTEGRATE_PDF
@@ -375,7 +549,7 @@ inline static double prbf(double x, double df)
 }
 #endif
 
-double get_spamicity(size_t robn, FLOAT P, FLOAT Q)
+static double get_spamicity(size_t robn, FLOAT P, FLOAT Q)
 {
     if (robn == 0)
     {
@@ -383,8 +557,8 @@ double get_spamicity(size_t robn, FLOAT P, FLOAT Q)
     }
     else
     {
-        double sp_df = 2.0 * robn * sp_esf;
-        double ns_df = 2.0 * robn * ns_esf;
+	double sp_df = 2.0 * robn * sp_esf;
+	double ns_df = 2.0 * robn * ns_esf;
 	double ln2 = log(2.0);					/* ln(2) */
 
 	score.robn = robn;
@@ -396,13 +570,13 @@ double get_spamicity(size_t robn, FLOAT P, FLOAT Q)
 	score.p_pr = prbf(-2.0 * score.p_ln, sp_df);		/* compute P */
 	score.q_pr = prbf(-2.0 * score.q_ln, ns_df);		/* compute Q */
   
-        if (!fBogotune && sp_esf >= 1.0 && ns_esf >= 1.0) {
-            score.spamicity = (1.0 + score.q_pr - score.p_pr) / 2.0;
-        } else if (score.q_pr < DBL_EPSILON && score.p_pr < DBL_EPSILON) {
-            score.spamicity = 0.5;
-        } else {
-            score.spamicity = score.q_pr / ( score.q_pr + score.p_pr);
-        }
+	if (!fBogotune && sp_esf >= 1.0 && ns_esf >= 1.0) {
+	    score.spamicity = (1.0 + score.q_pr - score.p_pr) / 2.0;
+	} else if (score.q_pr < DBL_EPSILON && score.p_pr < DBL_EPSILON) {
+	    score.spamicity = 0.5;
+	} else {
+	    score.spamicity = score.q_pr / (score.q_pr + score.p_pr);
+	}
     }
 
     return score.spamicity;
@@ -415,14 +589,14 @@ void msg_print_summary(const char *pfx)
 		      pfx, max_token_len+2, "N_P_Q_S_s_x_md", (unsigned long)score.robn, 
 		      score.p_pr, score.q_pr, score.spamicity);
 	(void)fprintf(fpo, "%s%-*s  %9.6f %9.6f %9.6f\n",
-		      pfx, max_token_len+2+6, " ", robs, robx, min_dev);
+		      pfx, max_token_len+2+6, " ", robs, robx, score.min_dev);
     }
     else {
 	/* Trim token to 22 characters to accomodate R's default line length of 80 */
 	(void)fprintf(fpo, "%s%-24s %6lu %9.2e %9.2e %9.2e %9.2e %9.2e %5.3f\n",
 		      pfx, "N_P_Q_S_s_x_md", (unsigned long)score.robn,
-		      score.p_pr, score.q_pr, score.spamicity, robs, robx, min_dev);
-     }
+		      score.p_pr, score.q_pr, score.spamicity, robs, robx, score.min_dev);
+    }
 }
 
 /* Done */
